@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2016 Aurimas Cernius
+ * Copyright (C) 2011-2017 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,14 +22,12 @@
 #include <config.h>
 #endif
 
-#include <boost/bind.hpp>
-#include <boost/format.hpp>
-
 #include <glibmm/i18n.h>
 #include <gtkmm/grid.h>
 #include <gtkmm/image.h>
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/stock.h>
+#include <gtkmm/separator.h>
 #include <gtkmm/separatortoolitem.h>
 #include <gtkmm/separatormenuitem.h>
 
@@ -156,12 +154,12 @@ namespace gnote {
   }
 
 
-  std::string NoteWindow::get_name() const
+  Glib::ustring NoteWindow::get_name() const
   {
     return m_name;
   }
 
-  void NoteWindow::set_name(const std::string & name)
+  void NoteWindow::set_name(const Glib::ustring & name)
   {
     m_name = name;
     signal_name_changed(m_name);
@@ -281,7 +279,7 @@ namespace gnote {
     }
   }
 
-  void NoteWindow::perform_search(const std::string & text)
+  void NoteWindow::perform_search(const Glib::ustring & text)
   {
     get_find_handler().perform_search(text);
   }
@@ -507,7 +505,7 @@ namespace gnote {
   }
 
 
-  void NoteWindow::on_note_tag_removed(const NoteBase::Ptr&, const std::string & tag)
+  void NoteWindow::on_note_tag_removed(const NoteBase::Ptr&, const Glib::ustring & tag)
   {
     if(tag == m_template_tag->normalized_name()) {
       m_template_widget->hide();
@@ -681,7 +679,7 @@ namespace gnote {
   }
 
 
-  void NoteFindHandler::perform_search(const std::string & txt)
+  void NoteFindHandler::perform_search(const Glib::ustring & txt)
   {
     cleanup_matches();
     if(txt.empty()) {
@@ -820,18 +818,14 @@ namespace gnote {
       m_widget.signal_backgrounded.connect(sigc::mem_fun(*this, &NoteTextMenu::on_widget_backgrounded));
 
       set_position(Gtk::POS_BOTTOM);
-      Gtk::Grid *main_grid = manage(new Gtk::Grid);
-      int main_top = 0;
-
-      Gtk::Grid *grid = manage(utils::create_popover_inner_grid());
-      int top = 0;
+      Gtk::Box *menu_box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
 
       Gtk::Widget *undo = manage(utils::create_popover_button("win.undo", _("_Undo")));
-      grid->attach(*undo, 0, top++, 1, 1);
+      menu_box->add(*undo);
 
       Gtk::Widget *redo = manage(utils::create_popover_button("win.redo", _("_Redo")));
-      grid->attach(*redo, 0, top++, 1, 1);
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
+      menu_box->add(*redo);
+      menu_box->add(*manage(new Gtk::Separator));
 
       // Listen to events so we can sensitize and
       // enable keybinding
@@ -846,7 +840,7 @@ namespace gnote {
 
       Gtk::Widget *highlight = manage(utils::create_popover_button("win.change-font-highlight", ""));
       auto label = static_cast<Gtk::Label*>(static_cast<Gtk::Bin*>(highlight)->get_child());
-      Glib::ustring markup = str(boost::format("<span background=\"yellow\">%1%</span>") % _("_Highlight"));
+      Glib::ustring markup = Glib::ustring::compose("<span background=\"yellow\">%1</span>", _("_Highlight"));
       label->set_markup_with_mnemonic(markup);
 
       Gtk::Widget *normal = create_font_size_item(_("_Normal"), NULL, "");
@@ -854,36 +848,37 @@ namespace gnote {
       Gtk::Widget *large = create_font_size_item(_("_Large"), "large", "size:large");
       Gtk::Widget *huge = create_font_size_item(_("Hu_ge"), "x-large", "size:huge");
 
-      grid = manage(utils::create_popover_inner_grid(&top));
-      grid->attach(*link, 0, top++, 1, 1);
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
+      menu_box->add(*link);
+      menu_box->add(*manage(new Gtk::Separator));
 
-      grid = manage(utils::create_popover_inner_grid(&top));
-      grid->set_name("formatting");
-      grid->attach(*bold, 0, top++, 1, 1);
-      grid->attach(*italic, 0, top++, 1, 1);
-      grid->attach(*strikeout, 0, top++, 1, 1);
-      grid->attach(*highlight, 0, top++, 1, 1);
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
+      auto box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
+      utils::set_common_popover_widget_props(*box);
+      box->set_name("formatting");
+      box->add(*bold);
+      box->add(*italic);
+      box->add(*strikeout);
+      box->add(*highlight);
+      menu_box->add(*box);
+      menu_box->add(*manage(new Gtk::Separator));
 
-      grid = manage(utils::create_popover_inner_grid(&top));
-      grid->set_name("font-size");
-      grid->attach(*small, 0, top++, 1, 1);
-      grid->attach(*normal, 0, top++, 1, 1);
-      grid->attach(*large, 0, top++, 1, 1);
-      grid->attach(*huge, 0, top++, 1, 1);
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
+      box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
+      utils::set_common_popover_widget_props(*box);
+      box->set_name("font-size");
+      box->add(*small);
+      box->add(*normal);
+      box->add(*large);
+      box->add(*huge);
+      menu_box->add(*box);
+      menu_box->add(*manage(new Gtk::Separator));
 
-      grid = manage(utils::create_popover_inner_grid(&top));
       Gtk::Widget *bullets = manage(utils::create_popover_button("win.enable-bullets", _("⦁ Bullets")));
-      grid->attach(*bullets, 0, top++, 1, 1);
+      menu_box->add(*bullets);
       Gtk::Widget *increase_indent = manage(utils::create_popover_button("win.increase-indent", _("→ Increase indent")));
-      grid->attach(*increase_indent, 0, top++, 1, 1);
+      menu_box->add(*increase_indent);
       Gtk::Widget *decrease_indent = manage(utils::create_popover_button("win.decrease-indent", _("← Decrease indent")));
-      grid->attach(*decrease_indent, 0, top++, 1, 1);
-      main_grid->attach(*grid, 0, main_top++, 1, 1);
+      menu_box->add(*decrease_indent);
 
-      add(*main_grid);
+      add(*menu_box);
 
       refresh_state();
     }
@@ -892,7 +887,7 @@ namespace gnote {
   {
     Gtk::Widget *widget = manage(utils::create_popover_button(action, ""));
     auto lbl = static_cast<Gtk::Label*>(static_cast<Gtk::Bin*>(widget)->get_child());
-    Glib::ustring m = str(boost::format("<%1%>%2%</%1%>") % markup % label);
+    Glib::ustring m = Glib::ustring::compose("<%1>%2</%1>", markup, label);
     lbl->set_markup_with_mnemonic(m);
     return widget;
   }
@@ -903,7 +898,7 @@ namespace gnote {
     auto lbl = static_cast<Gtk::Label*>(static_cast<Gtk::Bin*>(item)->get_child());
     Glib::ustring mrkp;
     if(markup != NULL) {
-      mrkp = str(boost::format("<span size=\"%1%\">%2%</span>") % markup % label);
+      mrkp = Glib::ustring::compose("<span size=\"%1\">%2</span>", markup, label);
     }
     else {
       mrkp = label;
