@@ -33,6 +33,7 @@
 
 #include "debug.hpp"
 #include "iactionmanager.hpp"
+#include "iconmanager.hpp"
 #include "ignote.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
@@ -64,6 +65,7 @@ namespace gnote {
     settings->signal_changed().connect(sigc::mem_fun(*this, &NoteRecentChanges::on_settings_changed));
 
     set_has_resize_grip(true);
+    set_icon_name(IconManager::GNOTE);
 
     m_search_notes_widget.signal_open_note
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note));
@@ -155,7 +157,11 @@ namespace gnote {
     left_box->attach(*m_all_notes_button, 0, 0, 1, 1);
 
     m_new_note_button = manage(new Gtk::Button);
-    m_new_note_button->set_label(_("New"));
+    image = manage(new Gtk::Image);
+    image->property_icon_name() = "list-add-symbolic";
+    image->property_icon_size() = GTK_ICON_SIZE_MENU;
+    m_new_note_button->set_image(*image);
+    m_new_note_button->set_tooltip_text(_("Create New Note"));
     m_new_note_button->add_accelerator("activate", get_accel_group(), GDK_KEY_N, Gdk::CONTROL_MASK, (Gtk::AccelFlags) 0);
     m_new_note_button->signal_clicked().connect(sigc::mem_fun(m_search_notes_widget, &SearchNotesWidget::new_note));
     m_new_note_button->show_all();
@@ -764,10 +770,7 @@ namespace gnote {
     std::map<Glib::ustring, Gtk::Widget*> submenus;
     Gtk::PopoverMenu *menu = manage(new Gtk::PopoverMenu);
     Gtk::Box *menu_box = manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
-    menu_box->property_margin_bottom() = 5;
-    menu_box->property_margin_top() = 5;
-    menu_box->property_margin_left() = 5;
-    menu_box->property_margin_right() = 5;
+    utils::set_common_popover_widget_props(*menu_box);
     FOREACH(Gtk::Widget *item, items) {
       if(item) {
         utils::PopoverSubmenu *submenu = dynamic_cast<utils::PopoverSubmenu*>(item);
