@@ -120,9 +120,21 @@ namespace gnote {
           : Gtk::Box(Gtk::ORIENTATION_VERTICAL)
           , PopoverSubmenu(submenu)
         {
-          set_common_popover_widget_props(*this);
+          utils::set_common_popover_widget_props(*this);
         }
       };
+
+      void set_common_popover_widget_props(Gtk::ModelButton & button)
+      {
+        button.set_use_underline(true);
+        button.property_margin_top() = 3;
+        button.property_margin_bottom() = 3;
+        auto lbl = dynamic_cast<Gtk::Label*>(button.get_child());
+        if(lbl) {
+          lbl->set_xalign(0.0f);
+        }
+        utils::set_common_popover_widget_props(button);
+      }
     }
 
 
@@ -292,7 +304,6 @@ namespace gnote {
       Gtk::ModelButton *item = new Gtk::ModelButton;
       gtk_actionable_set_action_name(GTK_ACTIONABLE(item->gobj()), action.c_str());
       item->set_label(label);
-      item->set_use_underline(true);
       set_common_popover_widget_props(*item);
       return item;
     }
@@ -303,7 +314,6 @@ namespace gnote {
       Gtk::ModelButton *button = new Gtk::ModelButton;
       button->property_menu_name() = submenu;
       button->set_label(label);
-      button->set_use_underline(true);
       set_common_popover_widget_props(*button);
       return button;
     }
@@ -320,6 +330,15 @@ namespace gnote {
       widget.property_hexpand() = true;
     }
 
+    void set_common_popover_widget_props(Gtk::Box & widget)
+    {
+      widget.property_margin_top() = 9;
+      widget.property_margin_bottom() = 9;
+      widget.property_margin_left() = 12;
+      widget.property_margin_right() = 12;
+      set_common_popover_widget_props(static_cast<Gtk::Widget&>(widget));
+    }
+
 
     void add_item_to_ordered_map(std::map<int, Gtk::Widget*> & dest, int order, Gtk::Widget *item)
     {
